==> jupyterlab_git-0.30.1.tar.gz: jupyterlab_git-0.30.1/jupyterlab_git/tests/test_tag.py <==
from pathlib import Path
from unittest.mock import Mock, call, patch

import pytest
import tornado

from jupyterlab_git.git import Git

from .testutils import FakeContentManager, maybe_future


@pytest.mark.asyncio
async def test_git_tag_success():
    with patch("jupyterlab_git.git.execute") as mock_execute:
        tag = "1.0.0"
        # Given
        mock_execute.return_value = maybe_future((0, tag, ""))

        # When
        actual_response = await Git(FakeContentManager(Path("/bin"))).tags(
            "test_curr_path"
        )

        # Then
        mock_execute.assert_called_once_with(
            ["git", "tag", "--list"],
            cwd=str(Path("/bin") / "test_curr_path"),
        )

        assert {"code": 0, "tags": [tag]} == actual_response


@pytest.mark.asyncio
async def test_git_tag_checkout_success():
    with patch("os.environ", {"TEST": "test"}):
        with patch("jupyterlab_git.git.execute") as mock_execute:
            tag = "mock_tag"
            # Given
            mock_execute.return_value = maybe_future((0, "", ""))

            # When
            actual_response = await Git(FakeContentManager(Path("/bin"))).tag_checkout(
                "test_curr_path", "mock_tag"
            )

            # Then
            mock_execute.assert_called_once_with(
                ["git", "checkout", "tags/{}".format(tag)],
                cwd=str(Path("/bin") / "test_curr_path"),
            )

            assert {
                "code": 0,
                "message": "Tag {} checked out".format(tag),
            } == actual_response

==> jupyterlab_git-0.42.0.tar.gz: jupyterlab_git-0.42.0/jupyterlab_git/tests/test_tag.py <==
from unittest.mock import patch

import pytest

from jupyterlab_git.git import Git

from .testutils import maybe_future


@pytest.mark.asyncio
async def test_git_tag_success():
    with patch("jupyterlab_git.git.execute") as mock_execute:
        tag = "1.0.0"
        # Given
        mock_execute.return_value = maybe_future((0, tag, ""))

        # When
        actual_response = await Git().tags("test_curr_path")

        # Then
        mock_execute.assert_called_once_with(
            ["git", "tag", "--list"],
            cwd="test_curr_path",
            timeout=20,
            env=None,
            username=None,
            password=None,
            is_binary=False,
        )

        assert {"code": 0, "tags": [tag]} == actual_response


@pytest.mark.asyncio
async def test_git_tag_checkout_success():
    with patch("os.environ", {"TEST": "test"}):
        with patch("jupyterlab_git.git.execute") as mock_execute:
            tag = "mock_tag"
            # Given
            mock_execute.return_value = maybe_future((0, "", ""))

            # When
            actual_response = await Git().tag_checkout("test_curr_path", "mock_tag")

            # Then
            mock_execute.assert_called_once_with(
                ["git", "checkout", "tags/{}".format(tag)],
                cwd="test_curr_path",
                timeout=20,
                env=None,
                username=None,
                password=None,
                is_binary=False,
            )

            assert {
                "code": 0,
                "message": "Tag {} checked out".format(tag),
            } == actual_response
